Title: [194471] trunk/Tools
Revision
194471
Author
aes...@apple.com
Date
2015-12-31 14:51:40 -0800 (Thu, 31 Dec 2015)

Log Message

Update the style checker to advise using WTFMove() instead of WTF::move()
https://bugs.webkit.org/show_bug.cgi?id=152601

Reviewed by Daniel Bates.

* Scripts/webkitpy/style/checkers/cpp.py:
(check_wtf_move):
* Scripts/webkitpy/style/checkers/cpp_unittest.py:
(WebKitStyleTest.test_wtf_move):

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (194470 => 194471)


--- trunk/Tools/ChangeLog	2015-12-31 22:49:09 UTC (rev 194470)
+++ trunk/Tools/ChangeLog	2015-12-31 22:51:40 UTC (rev 194471)
@@ -1,5 +1,17 @@
 2015-12-31  Andy Estes  <aes...@apple.com>
 
+        Update the style checker to advise using WTFMove() instead of WTF::move()
+        https://bugs.webkit.org/show_bug.cgi?id=152601
+
+        Reviewed by Daniel Bates.
+
+        * Scripts/webkitpy/style/checkers/cpp.py:
+        (check_wtf_move):
+        * Scripts/webkitpy/style/checkers/cpp_unittest.py:
+        (WebKitStyleTest.test_wtf_move):
+
+2015-12-31  Andy Estes  <aes...@apple.com>
+
         Fix warnings uncovered by migrating to WTF_MOVE
         https://bugs.webkit.org/show_bug.cgi?id=152601
 

Modified: trunk/Tools/Scripts/webkitpy/style/checkers/cpp.py (194470 => 194471)


--- trunk/Tools/Scripts/webkitpy/style/checkers/cpp_unittest.py	2015-12-31 22:49:09 UTC (rev 194470)
+++ trunk/Tools/Scripts/webkitpy/style/checkers/cpp_unittest.py	2015-12-31 22:51:40 UTC (rev 194471)
@@ -4801,19 +4801,19 @@
 
     def test_wtf_move(self):
         self.assert_lint(
-             'A a = WTF::move(b);',
+             'A a = WTFMove(b);',
              '',
              'foo.cpp')
 
         self.assert_lint(
             'A a = std::move(b);',
-            "Use 'WTF::move()' instead of 'std::move()'."
+            "Use 'WTFMove()' instead of 'std::move()'."
             "  [runtime/wtf_move] [4]",
             'foo.cpp')
 
         self.assert_lint(
             'A a = std::move(b);',
-            "Use 'WTF::move()' instead of 'std::move()'."
+            "Use 'WTFMove()' instead of 'std::move()'."
             "  [runtime/wtf_move] [4]",
             'foo.mm')
 
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Tools/Scripts/webkitpy/style/checkers/cpp.py	2015-12-31 22:49:09 UTC (rev 194470)
+++ trunk/Tools/Scripts/webkitpy/style/checkers/cpp.py	2015-12-31 22:51:40 UTC (rev 194471)
@@ -2256,7 +2256,7 @@
 
 
 def check_wtf_move(clean_lines, line_number, file_state, error):
     """Looks for use of 'std::move()' which should be replaced with 'WTF::move()'.
 
     Args:
       clean_lines: A CleansedLines instance containing the file.
@@ -2276,7 +2276,7 @@
     if not using_std_move:
         return
 
-    error(line_number, 'runtime/wtf_move', 4, "Use 'WTF::move()' instead of 'std::move()'.")
+    error(line_number, 'runtime/wtf_move', 4, "Use 'WTFMove()' instead of 'std::move()'.")
 
 
 def check_ctype_functions(clean_lines, line_number, file_state, error):
@@ -2256,7 +2256,7 @@
 
 def check_wtf_move(clean_lines, line_number, file_state, error):
-    """Looks for use of 'std::move()' which should be replaced with 'WTF::move()'.
+    """Looks for use of 'std::move()' which should be replaced with 'WTFMove()'.
 
     Args:

Modified: trunk/Tools/Scripts/webkitpy/style/checkers/cpp_unittest.py (194470 => 194471)

